==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/GeographicSymbolSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMarkerSeriesBaseDescriptionMetadata } from "./GeographicMarkerSeriesBaseDescriptionMetadata";
/**
 * @hidden
 */
export let GeographicSymbolSeriesBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicSymbolSeriesBaseDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicSymbolSeriesBaseDescriptionMetadata.a == null) {
                GeographicSymbolSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicSymbolSeriesBaseDescriptionMetadata.c(GeographicSymbolSeriesBaseDescriptionMetadata.a);
            }
            if (a.j(GeographicSymbolSeriesBaseDescriptionMetadata.a)) {
                return;
            }
            a.y(GeographicSymbolSeriesBaseDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMarkerSeriesBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            GeographicSymbolSeriesBaseDescriptionMetadata.b(a);
            a.z("GeographicSymbolSeriesBase", GeographicSymbolSeriesBaseDescriptionMetadata.a);
        }
    }
    GeographicSymbolSeriesBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(GeographicSymbolSeriesBaseDescriptionMetadata, 'GeographicSymbolSeriesBaseDescriptionMetadata');
    GeographicSymbolSeriesBaseDescriptionMetadata.a = null;
    return GeographicSymbolSeriesBaseDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GeographicSymbolSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GeographicMarkerSeriesBaseDescriptionMetadata } from "./GeographicMarkerSeriesBaseDescriptionMetadata";
/**
 * @hidden
 */
export let GeographicSymbolSeriesBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class GeographicSymbolSeriesBaseDescriptionMetadata extends Base {
        static b(a) {
            if (GeographicSymbolSeriesBaseDescriptionMetadata.a == null) {
                GeographicSymbolSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GeographicSymbolSeriesBaseDescriptionMetadata.c(GeographicSymbolSeriesBaseDescriptionMetadata.a);
            }
            if (a.k(GeographicSymbolSeriesBaseDescriptionMetadata.a)) {
                return;
            }
            a.aa(GeographicSymbolSeriesBaseDescriptionMetadata.a);
        }
        static c(a) {
            GeographicMarkerSeriesBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            GeographicSymbolSeriesBaseDescriptionMetadata.b(a);
            a.ab("GeographicSymbolSeriesBase", GeographicSymbolSeriesBaseDescriptionMetadata.a);
        }
    }
    GeographicSymbolSeriesBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(GeographicSymbolSeriesBaseDescriptionMetadata, 'GeographicSymbolSeriesBaseDescriptionMetadata');
    GeographicSymbolSeriesBaseDescriptionMetadata.a = null;
    return GeographicSymbolSeriesBaseDescriptionMetadata;
})();
